You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mynewt.apache.org by GitBox <gi...@apache.org> on 2018/04/20 00:54:18 UTC

[GitHub] ccollins476ad closed pull request #156: fix spelling errors

ccollins476ad closed pull request #156: fix spelling errors
URL: https://github.com/apache/mynewt-newt/pull/156
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/newt/newtutil/repo_version.go b/newt/newtutil/repo_version.go
index 7f7f6d9c..3271c405 100644
--- a/newt/newtutil/repo_version.go
+++ b/newt/newtutil/repo_version.go
@@ -172,13 +172,13 @@ func ParseRepoVersion(verStr string) (RepoVersion, error) {
 		case VERSION_STABILITY_LATEST:
 		default:
 			return RepoVersion{}, util.FmtNewtError(
-				"Unknown stability (%s) in verion %s", stability, verStr)
+				"Unknown stability (%s) in version %s", stability, verStr)
 		}
 	}
 	parts := strings.Split(sparts[0], ".")
 	if len(parts) > 3 {
 		return RepoVersion{},
-			util.FmtNewtError("Invalid verion string: %s", verStr)
+			util.FmtNewtError("Invalid version string: %s", verStr)
 	}
 
 	if strings.Trim(parts[0], " ") == "" ||
@@ -187,7 +187,7 @@ func ParseRepoVersion(verStr string) (RepoVersion, error) {
 		return RepoVersion{}, nil
 	}
 
 	// Assume no parts of the verion are specified.
 	ver := RepoVersion{
 		Major:     VERSION_FLOATING,
 		Minor:     VERSION_FLOATING,


 

----------------------------------------------------------------
@@ -187,7 +187,7 @@ func ParseRepoVersion(verStr string) (RepoVersion, error) {
 	}
 
-	// Assume no parts of the verion are specified.
+	// Assume no parts of the version are specified.
 	ver := RepoVersion{
 		Major:     VERSION_FLOATING,
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services